.. _model-account.move:

Account Move
============

The *Account Move* concept is used to record transactions in a
`Company's <company:model-company.company>` accounts.
In Tryton each account move is made up from several
`Account Move Lines <model-account.move.line>`.
These lines form the separate parts of the transaction as required by
`double-entry bookkeeping`_ principles.

Account moves are always tied to a specific accounting
`Period <model-account.period>`, and new account moves can only be created in
an open period.
All account moves are also entered into one of the
`Journals <model-account.journal>`.

An account move can be changed until it is posted.
Posting an account move permanently adds it to the company's accounts.
Only account moves whose line's debits and credits are balanced can be posted.

.. _`Double-entry bookkeeping`: https://en.wikipedia.org/wiki/Double-entry_bookkeeping

.. seealso::

   Account moves can be found by opening the main menu item:

      |Financial --> Entries --> Account Moves|__

      .. |Financial --> Entries --> Account Moves| replace:: :menuselection:`Financial --> Entries --> Account Moves`
      __ https://demo.tryton.org/model/account.move

Reports
-------

.. _report-account.move.general_journal:

General Journal
^^^^^^^^^^^^^^^

In Tryton the general journal lists all of the selected `Account Moves
<model-account.move>`.
It also includes details such as the accounts, debits and credits involved.

Wizards
-------

.. _wizard-account.move.cancel:

Cancel Moves
^^^^^^^^^^^^

The *Cancel Moves* wizard creates new account moves whose debits and credits
cancel out those from the original account moves.
If any of the `Account Move Lines <model-account.move.line>` that got cancelled
are in `Accounts <model-account.account>` that are marked as to be reconciled
then the original lines are `Reconciled <model-account.move.reconciliation>`
with those that cancel them out.

.. _model-account.move.line:

Account Move Line
=================

Each *Account Move Line* is used to represent a single debit, or credit, to
a specific `Account <model-account.account>`.

It is also used to record additional details about the transaction, such as:

* the amount in a second `Currency <currency:model-currency.currency>`,
* the `Party <party:model-party.party>` involved with the transaction,
* the date when the line matures and a payment for the (payable or receivable)
  line should happen, and
* how the amount is split up for `Tax <model-account.tax.line>` purposes.

Account move lines can only exist as part of an
`Account Move <model-account.move>`.
A valid line is part of an account move that has balanced debits and credits.
Once the account move that a line belongs to has been posted the main
properties of the line can no longer be changed.
These facts help ensure the integrity of the
`Company's <company:model-company.company>` accounts and the accounting reports
generated by Tryton.

Wizards
-------

.. _wizard-account.move.line.group:

Group Lines
^^^^^^^^^^^

The *Group Lines* wizard allows payable and/or receivable *Account Move Lines*
to be grouped together and a single unique payable or receivable account move
line is created for the net amount of the grouped lines.
The maturity date used for the newly created account move line is the
earliest maturity date from the lines that were grouped together.

.. _wizard-account.move.line.reschedule:

Reschedule Lines
^^^^^^^^^^^^^^^^

The *Reschedule Lines* wizard allows to reschedule payable or receivable
*Account Move Lines* by creating an account move line for each new maturity
date.

.. _wizard-account.move.reconcile_lines:

Reconcile Lines
^^^^^^^^^^^^^^^

The *Reconcile Lines* wizard matches together *Account Move Lines* from
the same account that have credits and debits which are equal.
If the selected account move lines do not balance then the wizard will offer
to create a write-off account move for the difference, so the reconciliation
can be completed.
When the reconciliation is done the lines are linked together using a new
`Reconciliation <model-account.move.reconciliation>`.

.. _wizard-account.move.unreconcile_lines:

Unreconcile Lines
^^^^^^^^^^^^^^^^^

The *Unreconcile Lines* wizard undoes a reconciliation.
It does this by removing the
`Reconciliation <model-account.move.reconciliation>` that linked together
the *Account Move Lines*.

.. note::

   Running this wizard will not reverse any other operations that may have
   been triggered when the reconciliation was initially performed.

.. _model-account.move.reconciliation:

Reconciliation
==============

In Tryton a *Reconciliation* groups together some
`Account Move Lines <model-account.move.line>` whose total debits and credits
balance.
These account move lines must all have the same
`Account <model-account.account>` and `Party <model-party.party>` and must
not already be part of another *Reconciliation*.

Each *Reconciliation* stores information about the reconciliation and when it
happened.

Wizards
-------

.. _wizard-account.reconcile:

Reconcile Accounts
^^^^^^^^^^^^^^^^^^

The *Reconcile Accounts* wizard is used to find and reconcile groups of
`Account Move Lines <model-account.move.line>` that have matching total
debits and credits, in `Accounts <model-account.account>` that are marked
for reconciliation.

The wizard goes through each account and `Party <party:model-party.party>`
in turn, and attempts to find the best possible reconciliations from the
unreconciled account move lines that should be considered.

.. seealso::

   The reconcile accounts wizard can be started from the main menu item:

      :menuselection:`Financial --> Processing --> Reconcile Accounts`

.. _model-account.move.reconcile.write_off:

Reconcile Write-off
===================

The *Reconcile Write-off* concept is used to configure which
`Journal <model-account.journal>` and debit or credit
`Accounts <model-account.account>` are used for write-offs generated when
`Reconciling Lines <wizard-account.move.reconcile_lines>`.

.. seealso::

   A list of the available reconcile write off settings can be found by
   opening the main menu item:

      |Financial --> Configuration --> Journals --> Write-off Methods|__

      .. |Financial --> Configuration --> Journals --> Write-off Methods| replace:: :menuselection:`Financial --> Configuration --> Journals --> Write-off Methods`
      __ https://demo.tryton.org/model/account.move.reconcile.write_off
